Center

Struct Center 

pub struct Center<K: Scalar = f64> {
    pub t: K,
    pub x: K,
    pub y: K,
}
A center of some transformation in ℍ²: a point, ideal point, or line.

Fields

t: Kx: Ky: K

Implementations

Source

impl<K: Scalar> Center<K>

pub fn classify(self) -> CenterKind<K>

Determine the kind of center.

In the case an operation gives a generic center object where you expect otherwise, see that individual operation for specific interpretations of each result. e.g. the intersection of two ultraparallel lines gives their unique common perpendicular.