pub struct Center<K: Scalar = f64> {
pub t: K,
pub x: K,
pub y: K,
}Expand description
A center of some transformation in ℍ²: a point, ideal point, or line.
Fields
t: Kx: Ky: KImplementations
Sourceimpl<K: Scalar> Center<K>
impl<K: Scalar> Center<K>
Sourcepub fn classify(self) -> CenterKind<K>
pub fn classify(self) -> CenterKind<K>
Determine the kind of center.
In the case an operation gives a generic center object where you expect otherwise, see that individual operation for specific interpretations of each result. e.g. the intersection of two ultraparallel lines gives their unique common perpendicular.